pub struct AnalyzeNode {
pub input: Option<Box<LogicalPlanNode>>,
pub verbose: bool,
pub analyze_level: Option<i32>,
pub analyze_categories: Option<ExplainAnalyzeCategoriesNode>,
pub format: i32,
}Fields
input: Option<Box<LogicalPlanNode>>verbose: boolanalyze_level: Option<i32>Statement-level override for datafusion.explain.analyze_level.
Absent means “fall back to session config”.
analyze_categories: Option<ExplainAnalyzeCategoriesNode>Statement-level override for datafusion.explain.analyze_categories.
Absent means “fall back to session config”.
format: i32Implementations
Sourceimpl AnalyzeNode
impl AnalyzeNode
Sourcepub fn analyze_level(&self) -> MetricType
pub fn analyze_level(&self) -> MetricType
Returns the enum value of analyze_level, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_analyze_level(&mut self, value: MetricType)
pub fn set_analyze_level(&mut self, value: MetricType)
Sets analyze_level to the provided enum value.
Sourcepub fn format(&self) -> ExplainFormat
pub fn format(&self) -> ExplainFormat
Returns the enum value of format, or the default if the field is set to an invalid enum value.
Sourcepub fn set_format(&mut self, value: ExplainFormat)
pub fn set_format(&mut self, value: ExplainFormat)
Sets format to the provided enum value.