#[repr(i32)]pub enum NullHandling {
Preserve = 0,
Drop = 1,
PreserveAndExpandEmpty = 2,
}Variants
Preserve = 0
Preserve nulls; empty lists produce no rows. The historical default.
Drop = 1
Drop both null and empty lists from the output.
PreserveAndExpandEmpty = 2
Preserve nulls, and additionally expand empty lists into a single NULL output row (outer-unnest semantics).
Implementations
Sourceimpl NullHandling
impl NullHandling
Sourceimpl NullHandling
impl NullHandling
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.